@@ -1,6 +1,6 @@
 !=======================================================================
 !
-!  PROGRAM  PHASE/0 2015.01 ($Rev: 440 $)
+!  PROGRAM  PHASE/0 2019.02 ($Rev: 570 $)
 !
 !  SUBROUINE:  readop, altv_2_rltv, string2values, inver3n,
 !              matpr3, inver2n, gnrt_op, gnrt_op_n,
@@ -35,7 +35,7 @@
 !   The activity of development of this program set has been supervised by Takahisa Ohno.
 !
 subroutine readop(ipri,kopr,altv,nfout,nfopgr,nfmatbp,Iparas,nopr,op,tau,af)
-! $Id: b_Crystal_Structure.f90 440 2015-08-03 07:18:01Z ktagami $
+! $Id: b_Crystal_Structure.f90 570 2017-04-21 20:34:50Z yamasaki $
 !
 !      read operation matrix OP(3,3,kopr) and TAU(3,kopr)
 !      from the file 'opgr.data'
@@ -1038,3 +1038,45 @@ logical function is_hexagonal(ca,cb,cc)
   if (abs(ca)<epsilon .and. abs(cb)<epsilon .and. abs(abs(cc)-0.5d0)<epsilon) is_hexagonal=.true.
 
 end function is_hexagonal
+
+subroutine get_latvec_from_brav_to_prim( b2pmat, altv_brav, altv_pr )
+  use m_Const_Parameters, only  : DP
+  implicit none
+
+  real(kind=DP), intent(in), dimension(3,3) :: b2pmat
+  real(kind=DP), intent(in)   :: altv_brav(3,3)
+  real(kind=DP), intent(out)    :: altv_pr(3,3)
+
+  real(kind=DP)                :: abcmat(3,3) = 0.d0
+
+  abcmat(1,:) = altv_brav(:,1)
+  abcmat(2,:) = altv_brav(:,2)
+  abcmat(3,:) = altv_brav(:,3)
+
+  abcmat = matmul(b2pmat,abcmat)
+  altv_pr(:,1) = abcmat(1,:)
+  altv_pr(:,2) = abcmat(2,:)
+  altv_pr(:,3) = abcmat(3,:)
+
+end subroutine get_latvec_from_brav_to_prim
+
+subroutine get_latvec_from_prim_to_brav( p2bmat, altv_pr, altv_brav )
+  use m_Const_Parameters, only  : DP
+  implicit none
+
+  real(kind=DP), intent(in), dimension(3,3) :: p2bmat
+  real(kind=DP), intent(in)    :: altv_pr(3,3)
+  real(kind=DP), intent(out)   :: altv_brav(3,3)
+
+  real(kind=DP)                :: abcmat(3,3) = 0.d0
+
+  abcmat(1,:) = altv_pr(:,1)
+  abcmat(2,:) = altv_pr(:,2)
+  abcmat(3,:) = altv_pr(:,3)
+
+  abcmat = matmul(p2bmat,abcmat)
+  altv_brav(:,1) = abcmat(1,:)
+  altv_brav(:,2) = abcmat(2,:)
+  altv_brav(:,3) = abcmat(3,:)
+
+end subroutine get_latvec_from_prim_to_brav
